==> areto-2.1.0.tgz: package/i18n/message/areto/ru.js <==
/**
 * @copyright Copyright (c) 2019 Maxim Khorin <maksimovichu@gmail.com>
 */
'use strict';

module.exports = {

    '<span class="not-set">[not set]</span>': '<span class="not-set">[не задано]</span>',

    'B': 'Б',
    'KiB': 'Кб',
    'MiB': 'Мб',
    'GiB': 'Гб',
    'TiB': 'Тб',
    'PiB': 'Пб',

    'Base class not found': 'Базовый класс не найден',

    'Date must be no less than {min}': 'Дата должна быть не ранее {min}',
    'Date must be no greater than {max}': 'Дата должна быть не позднее {max}',

    'Email': 'Электронный алрес',

    'File is not an image': 'Файл не является изображением',
    'File size cannot be smaller than {limit}': 'Размер файла не может быть менее {limit}',
    'File size cannot exceed {limit}': 'Размер файла не может превышать {limit}',

    'Height cannot be larger than {limit} px': 'Высота не может быть более {limit} пк',
    'Height cannot be smaller than {limit} px': 'Высота не может быть менее {limit} пк',

    'Invalid date': 'Недействительная дата',
    'Invalid email': 'Неверный адрес электронной почты',
    'Invalid file': 'Неверный файл',
    'Invalid filename': 'Неверное имя файла',
    'Invalid JSON': 'Неверный JSON',
    'Invalid ID': 'Неправильный ID',
    'Invalid IP address': 'Неправильный IP-адрес',
    'Invalid range': 'Недопустимый диапазон',
    'Invalid relation request': 'Неправильный запрос связи',
    'Invalid value': 'Неверное значение',
    'Invalid verification code': 'Неверный проверочный код',
    'Invalid url': 'Неверн ссылка',

    'No': 'Нет',
    'Number must be a integer': 'Число должно быть целым',

    'Only these file extensions are allowed: {extensions}': 'Допустимы только эти расширения файлов: {extensions}',
    'Only these file MIME types are allowed: {mimeTypes}': 'Допустимы только эти MIME-типы файлов: {mimeTypes}',

    'Password': 'Пароль',
    'Password Repeat': 'Повтор пароля',

    'Relation should contain at least {min} objects': 'Связанных значений должно быть не менее {min}',
    'Relation should contain at most {max} objects': 'Связанных значений должно быть не более {max}',

    'Value cannot be blank': 'Значение не может быть пустым',
    'Value does not exist': 'Значение не существует',
    'Value does not match pattern': 'Значение не соответствует шаблону',
    'Value has already been taken': 'Значение уже используется',
    'Value must be a number': 'Значение должно быть числом',
    'Value must be a string': 'Значение должно быть строкой',
    'Value must be "{requiredValue}"': 'Значение должно быть "{requiredValue}"',
    'Value must be "{true}" or "{false}"': 'Значение должно быть "{true}" или "{false}"',
    'Value must be repeated exactly': 'Значение должно быть повторено точно',
    'Value must not be equal to {compareValue}': 'Значение должно быть не равно {compareValue}',
    'Value must be greater than {compareValue}': 'Значение должно быть больше {compareValue}',
    'Value must be greater than or equal to "{compareValue}"': 'Значение должно быть больше или равно {compareValue}',
    'Value must be less than {compareValue}': 'Значение должно быть меньше "{compareValue}"',
    'Value must be less than or equal to {compareValue}': 'Значение должно быть меньше или равно {compareValue}',
    'Value must be no less than {min}': 'Значение должно быть не меньше {min}',
    'Value must be no greater than {max}': 'Значение должно быть не больше {max}',
    'Value must not be an IPv4 address': 'Значение не должно быть IPv4-адресом',
    'Value must not be an IPv6 address': 'Значение не должно быть IPv6-адресом',
    'Value should contain at least {min} chr.': 'Значение должно содержать не менее {min} симв.',
    'Value should contain at most {max} chr.': 'Значение должно содержать не более {max} симв.',
    'Value should contain {length} chr.': 'Значение должно содержать {length} симв.',
    'Verification code': 'Проверочный код',

    'Width cannot be larger than {limit} px': 'Ширина не может быть более {limit} пк',
    'Width cannot be smaller than {limit} px': 'Ширина должна быть не менее {limit} пк',

    'Yes': 'Да'
};

==> areto-2.4.0.tgz: package/i18n/message/areto/ru.js <==
/**
 * @copyright Copyright (c) 2019 Maxim Khorin <maksimovichu@gmail.com>
 */
'use strict';

module.exports = {

    '<span class="not-set">[not set]</span>': '<span class="not-set">[не задано]</span>',

    'B': 'Б',
    'KiB': 'Кб',
    'MiB': 'Мб',
    'GiB': 'Гб',
    'TiB': 'Тб',
    'PiB': 'Пб',

    'Base class not found': 'Базовый класс не найден',

    'Date must be no less than {min}': 'Дата должна быть не ранее {min}',
    'Date must be no greater than {max}': 'Дата должна быть не позднее {max}',

    'Email': 'Электронный алрес',

    'File is not an image': 'Файл не является изображением',
    'File size cannot be smaller than {limit}': 'Размер файла не может быть менее {limit}',
    'File size cannot exceed {limit}': 'Размер файла не может превышать {limit}',

    'Height cannot be larger than {limit} px': 'Высота не может быть более {limit} пк',
    'Height cannot be smaller than {limit} px': 'Высота не может быть менее {limit} пк',

    'Invalid date': 'Недействительная дата',
    'Invalid email': 'Неверный адрес электронной почты',
    'Invalid file': 'Неверный файл',
    'Invalid filename': 'Неверное имя файла',
    'Invalid JSON': 'Неверный JSON',
    'Invalid ID': 'Неправильный ID',
    'Invalid IP address': 'Неправильный IP-адрес',
    'Invalid range': 'Недопустимый диапазон',
    'Invalid relation request': 'Неправильный запрос связи',
    'Invalid spawn configuration': 'Неправильная конфигурация создания',
    'Invalid value': 'Неверное значение',
    'Invalid verification code': 'Неверный проверочный код',
    'Invalid url': 'Неверн ссылка',

    'No': 'Нет',
    'Number must be a integer': 'Число должно быть целым',

    'Only these file extensions are allowed: {extensions}': 'Допустимы только эти расширения файлов: {extensions}',
    'Only these file MIME types are allowed: {mimeTypes}': 'Допустимы только эти MIME-типы файлов: {mimeTypes}',

    'Password': 'Пароль',
    'Password Repeat': 'Повтор пароля',

    'Relation should contain at least {min} objects': 'Связанных значений должно быть не менее {min}',
    'Relation should contain at most {max} objects': 'Связанных значений должно быть не более {max}',

    'Value cannot be blank': 'Значение не может быть пустым',
    'Value does not exist': 'Значение не существует',
    'Value does not match pattern': 'Значение не соответствует шаблону',
    'Value has already been taken': 'Значение уже используется',
    'Value must be a number': 'Значение должно быть числом',
    'Value must be a string': 'Значение должно быть строкой',
    'Value must be "{requiredValue}"': 'Значение должно быть "{requiredValue}"',
    'Value must be "{true}" or "{false}"': 'Значение должно быть "{true}" или "{false}"',
    'Value must be equal to {compareValue}': 'Значение должно быть равно {compareValue}',    
    'Value must not be equal to {compareValue}': 'Значение должно быть не равно {compareValue}',
    'Value must be greater than {compareValue}': 'Значение должно быть больше {compareValue}',
    'Value must be greater than or equal to "{compareValue}"': 'Значение должно быть больше или равно {compareValue}',
    'Value must be less than {compareValue}': 'Значение должно быть меньше "{compareValue}"',
    'Value must be less than or equal to {compareValue}': 'Значение должно быть меньше или равно {compareValue}',
    'Value must be no less than {min}': 'Значение должно быть не меньше {min}',
    'Value must be no greater than {max}': 'Значение должно быть не больше {max}',
    'Value must not be an IPv4 address': 'Значение не должно быть IPv4-адресом',
    'Value must not be an IPv6 address': 'Значение не должно быть IPv6-адресом',
    'Value should contain at least {min} chr.': 'Значение должно содержать не менее {min} симв.',
    'Value should contain at most {max} chr.': 'Значение должно содержать не более {max} симв.',
    'Value should contain {length} chr.': 'Значение должно содержать {length} симв.',
    'Verification code': 'Проверочный код',

    'Width cannot be larger than {limit} px': 'Ширина не может быть более {limit} пк',
    'Width cannot be smaller than {limit} px': 'Ширина должна быть не менее {limit} пк',

    'Yes': 'Да'
};
